Rename CONFIG_SYS_TEXT_BASE to CONFIG_TEXT_BASE

The current name is inconsistent with SPL which uses CONFIG_SPL_TEXT_BASE
and this makes it imposible to use CONFIG_VAL().

Rename it to resolve this problem.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/arch/microblaze/cpu/relocate.c b/arch/microblaze/cpu/relocate.c
index b00d02b..7a15fb2 100644
--- a/arch/microblaze/cpu/relocate.c
+++ b/arch/microblaze/cpu/relocate.c
@@ -19,7 +19,7 @@
  * @rela_start: rela section start
  * @rela_end: rela section end
  * @dyn_start: dynamic section start
  * @origin_addr: address where u-boot starts(doesn't need to be CONFIG_SYS_TEXT_BASE)
  */
 void mb_fix_rela(u32 reloc_addr, u32 verbose, u32 rela_start,
 		 u32 rela_end, u32 dyn_start, u32 origin_addr)
@@ -29,9 +29,9 @@
 	/*
 	 * Return in case u-boot.elf is used directly.
 	 * Skip it when u-boot.bin is loaded to different address than
 	 * CONFIG_SYS_TEXT_BASE. In this case relocation is necessary to run.
 	 */
-	if (reloc_addr == CONFIG_SYS_TEXT_BASE) {
+	if (reloc_addr == CONFIG_TEXT_BASE) {
 		debug_cond(verbose,
 			   "Relocation address is the same - skip relocation\n");
 		return;
@@ -19,7 +19,7 @@
  * @rela_end: rela section end
  * @dyn_start: dynamic section start
- * @origin_addr: address where u-boot starts(doesn't need to be CONFIG_SYS_TEXT_BASE)
+ * @origin_addr: address where u-boot starts(doesn't need to be CONFIG_TEXT_BASE)
  */
 void mb_fix_rela(u32 reloc_addr, u32 verbose, u32 rela_start,
@@ -29,9 +29,9 @@
 	 * Return in case u-boot.elf is used directly.
 	 * Skip it when u-boot.bin is loaded to different address than
-	 * CONFIG_SYS_TEXT_BASE. In this case relocation is necessary to run.
+	 * CONFIG_TEXT_BASE. In this case relocation is necessary to run.
 	 */